@@ -287,6 +287,7 @@ acm_exit (void)
 * ja:ACM基本                                                                  *
 *                                                                             *
 ******************************************************************************/
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
 static gint
 acm_get_handler_list_compare (gconstpointer a,
                               gconstpointer b)
@@ -302,6 +303,7 @@ acm_get_handler_list_callback (gpointer   key,
 {
   *glist = g_list_insert_sorted (*glist, key, acm_get_handler_list_compare);
 }
+#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
 
 
 /*  ja:登録されているタグを取得する
@@ -311,9 +313,11 @@ acm_get_tag_list (void)
 {
   GList *glist = NULL;
 
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
   if (ghash_tag)
     g_hash_table_foreach (ghash_tag,
                                 (GHFunc)acm_get_handler_list_callback, &glist);
+#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
   return glist;
 }
 
@@ -1141,10 +1145,17 @@ acm_decompress_begin (AcmObject          *acm_object,
   gboolean result;
   WaveFormatEx *wfx_out;
 
-  if (!acm_object || !acm_object->hDrvr || !wfx
+  if (!acm_object
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+                        || !acm_object->hDrvr
+#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
+                        || !wfx
                         || wfx_get_format_tag (wfx) != acm_object->tag
                         || wf_header_bytes (wfx) != acm_object->format_size
-                        || acm_object->stat != 0)
+#if defined (G_OS_WIN32) || defined (USE_W32LDR)
+                        || acm_object->stat != 0
+#endif /* defined (G_OS_WIN32) || defined (USE_W32LDR) */
+                        )
     return FALSE;
   wfx_out = g_malloc (acm_decompress_get_format_size (acm_object, wfx));
   result = acm_decompress_get_format (acm_object, wfx, wfx_out)
