@@ -73,8 +73,7 @@ acm_open (const guint16 tag);
 /*  ja:Codecを閉じる
     acm_object,AcmObject
            RET,TRUE:正常終了,FALSE:エラー                                   */
-gboolean
-acm_close (AcmObject *acm_object);
+#define acm_close(acm_object) acm_unref(acm_object)
 
 
 /*  ja:Codecの参照数を増やす
@@ -91,7 +90,7 @@ gboolean
 acm_unref (AcmObject *acm_object);
 
 
-/*  ja:Codecをコピーする
+/*  ja:Codecを複製する
     acm_object,AcmObject
            RET,AcmObject,NULL:エラー                                        */
 AcmObject *
