@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -112,14 +112,18 @@ typedef struct _AviOptions
 } AviOptions;
 struct _AviSave
 {
+  gchar *extension;             /* ja:保存するファイルの推奨拡張子 */
   gint type;                    /* ja:保存するファイルの種類 */
   /* ja:AVI/WAVE固有 */
   AviOptions *avi_opt;          /* ja:オプション */
-  /* ja:ビットマップ/WAVE固有 */
+  /* ja:ビットマップ/GdkPixbuf/WAVE固有 */
   gint stream;                  /* ja:対象ストリーム */
-  /* ja:ビットマップ固有 */
+  /* ja:ビットマップ/GdkPixbuf固有 */
   gint start;                   /* ja:最初のフレーム */
   gint end;                     /* ja:最後のフレーム */
+  /* ja:GdkPixbuf固有 */
+  gchar *name;                  /* en:bmp,ico,jpeg,png,tiff,... */
+  gchar **keys, **values;       /* ja:オプション */
 };
 
 
@@ -230,6 +234,13 @@ avi_file_open_memory (gconstpointer  data,
                       gint          *type);
 
 
+/*  ja:GdkPixbufからAVIファイル構造体を求める
+    pixbuf,GdkPixbuf
+       RET,AVIファイル構造体,NULL:エラー                                    */
+AviFile *
+avi_file_open_pixbuf (GdkPixbuf *pixbif);
+
+
 /*  ja:AVIファイル構造体を解放する
     avi_file,AVIファイル構造体
          RET,TRUE:正常終了,FALSE:エラー                                     */
