@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,8 +42,9 @@ extern "C" {
 #define AVI_FILE_AVI        1
 #define AVI_FILE_GSR        2
 #define AVI_FILE_BITMAP     3
-#define AVI_FILE_WAVE       4
-#define AVI_FILE_SCENARIO   5
+#define AVI_FILE_PIXBUF     4
+#define AVI_FILE_WAVE       5
+#define AVI_FILE_SCENARIO   6
 
 
 typedef struct _AviEdit AviEdit;
@@ -378,6 +379,13 @@ AviEdit *
 avi_edit_open_from_memory (gconstpointer data);
 
 
+/*  ja:AVIをGdkPixbufから開く
+    pixbuf,データ
+       RET,AVI編集ハンドル,NULL:エラー                                      */
+AviEdit *
+avi_edit_open_from_pixbuf (GdkPixbuf *pixbuf);
+
+
 /*  ja:AVIを閉じる
     avi_edit,AVI編集ハンドル
          RET,TRUE:正常終了,FALSE:エラー                                     */
@@ -432,7 +440,7 @@ avi_frame_get_bitmap (AviFrame   *avi_frame,
         width,幅
        height,高さ
           RET,RAWへのポインタ,NULL:エラー                               */
-guint8 *
+guchar *
 avi_frame_get_raw (AviFrame   *avi_frame,
                    const gint  pos,
                    const gint  width,
@@ -557,7 +565,14 @@ avi_save_free (AviSave *avi_save);
     avi_save,オプション
          RET,ファイルタイプ,-1:エラー                                       */
 gint
-avi_save_type (AviSave *avi_save);
+avi_save_get_type (AviSave *avi_save);
+
+
+/*  ja:保存されるファイルの拡張子を返す
+    avi_save,オプション
+         RET,拡張子,NULL:エラー                                             */
+const gchar *
+avi_save_get_extension (AviSave *avi_save);
 
 
 /*  ja:すべて保存されるかチェックする
