@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -81,18 +81,15 @@ avi_play_get_type (void)
 static void
 avi_play_class_init (AviPlayClass *klass)
 {
-  GObjectClass *gobject_class;
   GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
 
-  gobject_class = (GObjectClass *)klass;
   object_class = (GtkObjectClass *)klass;
-  widget_class = (GtkWidgetClass *)klass;
-
   parent_class = g_type_class_peek_parent (klass);
 
   object_class->destroy = avi_play_destroy;
 
+  klass->status = NULL;
+
   avi_play_signals[STATUS_SIGNAL]
         = g_signal_new ("status",
                 G_TYPE_FROM_CLASS (klass),
