@@ -105,8 +105,8 @@ avi_edit_at_scenario (AviEdit    *avi_edit,
             }
           text[leng++] = '\n';
           text[leng] = '\0';
-          start_n++;
           samples_n--;
+          start_n++;
         }
       else
         {
@@ -132,7 +132,7 @@ gchar *
 avi_edit_to_scenario (AviEdit        **avi_edit,
                       const gboolean   interleave)
 {
-  gchar *text, *scenario = NULL;
+  gchar *scenario = NULL;
   gint i, leng, length = 0;
 
   if (!avi_edit)
@@ -142,6 +142,8 @@ avi_edit_to_scenario (AviEdit        **avi_edit,
   length = g_strlen (scenario);
   for (i = 0; avi_edit[i]; i++)
     {
+      gchar *text;
+
       switch (avi_edit_type (avi_edit[i]))
         {
           case AVI_TYPE_VIDEO:
@@ -181,8 +183,13 @@ avi_edit_to_scenario (AviEdit        **avi_edit,
       length += leng;
       if (avi_edit_get_name (avi_edit[i]))
         {
-          text = g_strdup_printf ("%d,name,\'%s\'\n",
-                                        i, avi_edit_get_name (avi_edit[i]));
+          gchar *name;
+
+          name = g_strescape (avi_edit_get_name (avi_edit[i]), NULL);
+          text = name ? g_strdup_printf ("%d,name,\"%s\"\n", i, name)
+                      : g_strdup_printf ("%d,name,\'%s\'\n", i,
+                                            avi_edit_get_name (avi_edit[i]));
+          g_free (name);
           leng = g_strlen (text);
           scenario = g_realloc (scenario,
                                         (length + leng + 2) * sizeof (gchar));
@@ -238,11 +245,11 @@ avi_edit_to_scenario (AviEdit        **avi_edit,
           for (i = 0; i < streams; i++)
             if (pos[i] < avi_edit_length (avi_edit[i]))
               {
+                gchar *text;
                 gint samples;
 
-                samples = current > 0 ? i == current ? 1 : avi_time_to_sample
-                        (avi_edit[i], avi_time_from_sample (avi_edit[current],
-                                                    pos[current] + 1)) - pos[i]
+                samples = current > 0 ? i == current ? 1 : avi_time_sync_sample
+                    (avi_edit[current], pos[current] + 1, avi_edit[i]) - pos[i]
                             : avi_time_to_sample (avi_edit[i], timer) - pos[i];
                 text = avi_edit_at_scenario (avi_edit[i], i, pos[i], samples);
                 if (text)
@@ -275,6 +282,8 @@ avi_edit_to_scenario (AviEdit        **avi_edit,
       /* ja:非インターリーブ */
       for (i = 0; avi_edit[i]; i++)
         {
+          gchar *text;
+
           text = avi_edit_at_scenario (avi_edit[i], i,
                                             0, avi_edit_length (avi_edit[i]));
           leng = g_strlen (text);
@@ -297,14 +306,23 @@ AviEdit **
 avi_edit_from_scenario (const gchar *scenario)
 {
   gchar **lines, *text;
-  gint i = 0, j = 0, count = 0;
+  gint i, j = 0, count = 0;
   AviEdit **avi_edit = NULL;
-  AviFile *avi_file;
 
   if (!scenario)
     return NULL;
-  /* ja:便宜改行を真の改行に変換する */
   text = g_strdup (scenario);
+  /* ja:CRLFをLFに変換する */
+  for (i = 0; text[i] != '\0'; i++)
+    if (text[i] != '\r' || text[i + 1] != '\n')
+      text[j++] = text[i];
+  text[j] = '\0';
+  /* ja:CRをLFに変換する */
+  for (i = 0; text[i] != '\0'; i++)
+    if (text[i] == '\r')
+      text[i] = '\n';
+  /* ja:便宜改行を真の改行に変換する */
+  i = j = 0;
   while (text[i] != '\0')
     if (text[i] == '\\' && text[i + 1] == '\n')
       i += 2;
@@ -326,9 +344,14 @@ avi_edit_from_scenario (const gchar *scenario)
           {
             quote[0] = !quote[0];
           }
-        else if ((lines[i])[j] == '\"' && !quote[0])
+        else if ((lines[i])[j] == '\"' && !quote[0] && !quote[1])
           {
-            quote[1] = !quote[1];
+            quote[1] = TRUE;
+          }
+        else if ((lines[i])[j] == '\"' && !quote[0] && quote[1]
+                                                && (lines[i])[j - 1] != '\\')
+          {
+            quote[1] = FALSE;
           }
         else if (!quote[0] && !quote[1])
           {
@@ -346,15 +369,29 @@ avi_edit_from_scenario (const gchar *scenario)
       cmd = g_strsplit (lines[i], "\n", 0);
       for (j = 0; cmd[j]; j++)
         {
-          gint leng;
+          gsize leng;
 
           g_strstrip (cmd[j]);
           leng = g_strlen (cmd[j]) - 1;
-          if (leng >= 1 && (((cmd[j])[0] == '\'' && (cmd[j])[leng] == '\'')
-                        || ((cmd[j])[0] == '\"' && (cmd[j])[leng] == '\"')))
+          if (leng >= 1)
             {
-              g_memmove (cmd[j], cmd[j] + 1, --leng * sizeof (gchar));
-              (cmd[j])[leng] = '\0';
+              if ((cmd[j])[0] == '\'' && (cmd[j])[leng] == '\'')
+                {
+                  g_memmove (cmd[j], cmd[j] + 1, --leng * sizeof (gchar));
+                  (cmd[j])[leng] = '\0';
+                }
+              else if ((cmd[j])[0] == '\"' && (cmd[j])[leng] == '\"')
+                {
+                  gchar *tmp;
+
+                  (cmd[j])[leng] = '\0';
+                  tmp = g_strcompress (cmd[j] + 1);
+                  if (tmp)
+                    {
+                      g_free (cmd[j]);
+                      cmd[j] = tmp;
+                    }
+                }
             }
         }
       if (cmd[0] && cmd[1]
@@ -464,6 +501,7 @@ avi_edit_from_scenario (const gchar *scenario)
           else if (g_ascii_strcasecmp (cmd[1], "file") == 0 && cmd[2])
             {
               gint param, type;
+              AviFile *avi_file;
 
               if (!cmd[3] || !misc_str_to_val (&param, cmd[3], 10, FALSE))
                 param = 0;
@@ -535,34 +573,29 @@ avi_edit_from_scenario (const gchar *scenario)
                                 && size > BMIH_SIZE)
             {
               gsize s;
-              guint8 *a;
+              gpointer a;
 
               a = misc_str_to_array (&s, 8, cmd[3], 16, FALSE);
               if (a && s == size && bm_all_bytes (a) == size)
                 {
-                  avi_file = g_malloc0 (sizeof (AviFile));
-                  size = bm_image_bytes (a);
-                  s = bm_header_bytes (a);
-                  avi_file->avi_memory = avi_memory_dup (a + s, size);
-                  avi_file->length = 1;     /* ja:有効な範囲 */
-                  avi_file->entries = 1;    /* ja:インデックスの数 */
-                  /* ja:ビデオ固有 */
-                  avi_file->handler = AVI_STREAM_COMP_DIB;
-                  avi_file->bmih = g_realloc (a, s);
-                  /* ja:インデックス */
-                  avi_file->index = g_malloc0 (sizeof (AviIndex));
-                  avi_file->index[0].size = size;
-                  if (!avi_edit[stream]->file)
+                  gint type;
+                  AviFile *avi_file;
+
+                  avi_file = avi_file_open_memory (a, &type);
+                  if (avi_file && type == AVI_TYPE_VIDEO)
                     {
-                      /* ja:先頭 */
-                      avi_edit[stream]->file = avi_file;
-                    }
-                  else
-                    {
-                      /* ja:追加 */
-                      avi_edit[stream]->file->next = avi_file;
-                      avi_file->prev = avi_edit[stream]->file;
-                      avi_edit[stream]->file = avi_file;
+                      if (!avi_edit[stream]->file)
+                        {
+                          /* ja:先頭 */
+                          avi_edit[stream]->file = avi_file;
+                        }
+                      else
+                        {
+                          /* ja:追加 */
+                          avi_edit[stream]->file->next = avi_file;
+                          avi_file->prev = avi_edit[stream]->file;
+                          avi_edit[stream]->file = avi_file;
+                        }
                     }
                 }
             }
@@ -577,6 +610,8 @@ avi_edit_from_scenario (const gchar *scenario)
           /* ja:サンプル数 */
           if (avi_edit[i]->file)
             {
+              AviFile *avi_file;
+
               while (avi_edit[i]->file->prev)
                 avi_edit[i]->file = avi_edit[i]->file->prev;
               for (avi_file = avi_edit[i]->file; avi_file;
