@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -289,6 +289,13 @@ typedef struct _RgbQuad { guint8 dummy[RGBQUAD_SIZE]; } RgbQuad;
 #define bm_all_bytes(bmih) (bm_header_bytes(bmih)+bm_image_bytes(bmih))
 
 
+/*  ja:ビットマップのピクセルデータのアドレスを求める
+    bmih,BitmapInfoHeader構造体へのポインタ
+     RET,ピクセルデータへのポインタ                                         */
+#define bm_image_pointer(bmih)                                              \
+                        ((gpointer)((guint8 *)(bmih)+bm_header_bytes(bmih)))
+
+
 /******************************************************************************
 *                                                                             *
 * ja:ビットマップ加工関数                                                     *
