@@ -1,6 +1,6 @@
 /*
     fileio
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -75,16 +75,6 @@ extern "C" {
 #define FILEIO_SHARE_DENY           0
 #define FILEIO_ACCESS_ALL           (FILEIO_ACCESS_READ | FILEIO_ACCESS_WRITE)
 #define FILEIO_SHARE_ALL            (FILEIO_SHARE_READ | FILEIO_SHARE_WRITE)
-#define FILEIO_TEST_IS_REGULAR      (1 << 0)
-#define FILEIO_TEST_IS_SYMLINK      (1 << 1)
-#define FILEIO_TEST_IS_DIR          (1 << 2)
-#define FILEIO_TEST_IS_EXECUTABLE   (1 << 3)
-#define FILEIO_TEST_EXISTS          (1 << 4)
-#define FILEIO_ICON_SIZE_SMALL      0
-#define FILEIO_ICON_SIZE_LARGE      1
-
-
-#define fileio_isfile(file) g_file_test(file,G_FILE_TEST_EXISTS)
 
 
 typedef struct _FileIO FileIO;
@@ -111,15 +101,6 @@ typedef struct _FileIOSysTime
 * ja:ファイル名関数群                                                         *
 *                                                                             *
 ******************************************************************************/
-/*  ja:ファイルの存在確認
-    file,ファイル名
-    test,条件
-     RET,TRUE:合致する,FALSE:合致しない                                     */
-gboolean
-fileio_test (const gchar *file,
-             const guint test);
-
-
 /*  ja:ファイルのフルパスを取得する
     file,ファイル名
      RET,フルパス                                                           */
@@ -162,11 +143,24 @@ fileio_open (const gchar *file,
              const guint  mode);
 
 
-/*  ja:ファイルポインタを閉じる
+/*  ja:ファイルポインタの参照数を増やす
     fio,ファイルポインタ
     RET,TRUE:正常終了,FALSE:エラー                                          */
 gboolean
-fileio_close (FileIO *fio);
+fileio_ref (FileIO *fio);
+
+
+/*  ja:ファイルポインタの参照数を減らす
+    fio,ファイルポインタ
+    RET,TRUE:正常終了,FALSE:エラー                                          */
+gboolean
+fileio_unref (FileIO *fio);
+
+
+/*  ja:ファイルポインタを閉じる
+    fio,ファイルポインタ
+    RET,TRUE:正常終了,FALSE:エラー                                          */
+#define fileio_close(fio) fileio_unref(fio)
 
 
 /*  ja:ファイルから読み込む
@@ -325,11 +319,11 @@ fileio_getsystime (FileIOTime    *ftime,
 ******************************************************************************/
 /*  ja:ファイルのアイコンを取得する
          file,ファイル名
-    icon_size,FILEIO_ICON_SIZE_SMALL/FILEIO_ICON_SIZE_LARGE
+    icon_size,アイコンサイズ
           RET,pixbuf,NULL:エラー                                            */
 GdkPixbuf *
 fileio_extract_icon (const gchar *file,
-                     const guint  icon_size);
+                     GtkIconSize  icon_size);
 
 
 #ifdef __cplusplus
