@@ -1,6 +1,6 @@
 /*
     orzmdi
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -113,7 +113,7 @@ file_add_edit (OrzMdi    *mdi,
 
   tab0->same = -2;
   /* ja:ファイル名を調べる */
-  glist = gtk_container_children (GTK_CONTAINER (mdi));
+  glist = gtk_container_get_children (GTK_CONTAINER (mdi));
   /* ja:同名同パスを調べる */
   for (i = g_list_length (glist) - 1; i >= 0; i--)
     {
@@ -178,7 +178,7 @@ file_remove_edit (OrzMdi      *mdi,
   OrzMdiTab *tab1;
 
   /* ja:ファイル名を調べる */
-  glist = gtk_container_children (GTK_CONTAINER (mdi));
+  glist = gtk_container_get_children (GTK_CONTAINER (mdi));
   name0 = g_path_get_basename (tab0->file);
   for (i = g_list_length (glist) - 1; i >= 0; i--)
     {
@@ -335,26 +335,26 @@ orz_mdi_switch_page (GtkNotebook     *notebook,
 static void
 orz_mdi_class_init (OrzMdiClass *klass)
 {
-  GObjectClass *gobject_class;
-  GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
   GtkContainerClass *container_class;
   GtkNotebookClass *notebook_class;
 
-  gobject_class = (GObjectClass *) klass;
-  object_class = (GtkObjectClass *) klass;
-  widget_class = (GtkWidgetClass *) klass;
   container_class = (GtkContainerClass *) klass;
   notebook_class = (GtkNotebookClass *) klass;
 
   parent_class = g_type_class_peek_parent (klass);
-
   container_class->remove = orz_mdi_remove;
   notebook_class->switch_page = orz_mdi_switch_page;
 
+  klass->add_window = NULL;
+  klass->change_window = NULL;
+  klass->close_window = NULL;
+  klass->remove_window = NULL;
+  klass->reorder_window = NULL;
+  klass->switch_window = NULL;
+
   orz_mdi_signals[ADD_WINDOW_SIGNAL]
                 = g_signal_new ("add_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, add_window),
                                 NULL, NULL,
@@ -364,7 +364,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[CHANGE_WINDOW_SIGNAL]
                 = g_signal_new ("change_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, change_window),
                                 NULL, NULL,
@@ -374,7 +374,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[CLOSE_WINDOW_SIGNAL]
                 = g_signal_new ("close_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, close_window),
                                 NULL, NULL,
@@ -384,7 +384,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[REMOVE_WINDOW_SIGNAL]
                 = g_signal_new ("remove_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, remove_window),
                                 NULL, NULL,
@@ -394,7 +394,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[REORDER_WINDOW_SIGNAL]
                 = g_signal_new ("reorder_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, reorder_window),
                                 NULL, NULL,
@@ -404,7 +404,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[SWITCH_WINDOW_SIGNAL]
                 = g_signal_new ("switch_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, switch_window),
                                 NULL, NULL,
@@ -874,7 +874,7 @@ orz_mdi_get_n_pages (OrzMdi *mdi)
     {
       GList *glist;
 
-      glist = gtk_container_children (GTK_CONTAINER (mdi));
+      glist = gtk_container_get_children (GTK_CONTAINER (mdi));
       if (glist)
         {
           n_pages = g_list_length (glist);
