@@ -134,7 +134,7 @@ command_frame (GtkWidget *widget,
 
 
 void
-command_conf (GtkWidget *widget,
+command_pref (GtkWidget *widget,
               gpointer   user_data);
 
 
