@@ -33,6 +33,15 @@ extern "C" {
 * ja:一般関数群                                                               *
 *                                                                             *
 ******************************************************************************/
+/*  ja:フレームの数を取得する
+     vmaid,ウインドウ情報                                                   */
+#define get_sx_frame(vmaid) MAX(((VmaidWindow *)vmaid)->selfrm              \
+                    ?(((VmaidWindow *)vmaid)->drawing->allocation.width-4)  \
+                                        /   ((VmaidWindow *)vmaid)->width-2 \
+                    :(((VmaidWindow *)vmaid)->drawing->allocation.width-2)  \
+                                            /((VmaidWindow *)vmaid)->width,1)
+
+
 /*  ja:キャレットを消す
     vmaid,ウインドウ情報                                                    */
 void
@@ -65,6 +74,12 @@ clear_sel (VmaidWindow *vmaid,
            const gint   top);
 
 
+/*  ja:最小のウインドウサイズを設定する
+     vmaid,ウインドウ情報                                                   */
+void
+set_usize (VmaidWindow *vmaid);
+
+
 /*  ja:リストから削除する
       d,リストの先頭
     RET,削除したリストの数                                                  */
@@ -87,11 +102,6 @@ gboolean
 prompt_close (VmaidWindow *vmaid);
 
 
-/******************************************************************************
-*                                                                             *
-* ja:高レベル関数群                                                           *
-*                                                                             *
-******************************************************************************/
 /*  ja:最大フレーム数を求める
      vmaid,ウインドウ情報
     stream,有効なストリーム
@@ -101,6 +111,18 @@ get_max_frame (VmaidWindow *vmaid,
                const gint   stream);
 
 
+/******************************************************************************
+*                                                                             *
+* ja:高レベル関数群                                                           *
+*                                                                             *
+******************************************************************************/
+/*  ja:フレームを反転する(独立スレッド)
+    avi_edit,AVI編集構造体
+         RET,TRUE:正常終了,FALSE:エラー                                     */
+gboolean
+reverse_frame (AviEdit *avi_edit);
+
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
