@@ -37,14 +37,17 @@ signal_style_set (GtkWidget *widget,
                   GtkStyle  *style,
                   gpointer   user_data)
 {
+  gboolean success[4];
   gint i, ascent, height;
 
-  /* ja:システム色 */
   style = gtk_widget_get_style (widget);
+  /* ja:システム色 */
   system_color[0] = style->text[0];
   system_color[1] = style->base[0];
-  system_color[2] = style->fg[3];
+  system_color[2] = style->dark[0];
   system_color[3] = style->bg[3];
+  gdk_colormap_alloc_colors (gdk_colormap_get_system (),
+                                        system_color, 4, FALSE, TRUE, success);
   if (system_font)
     gdk_font_unref (system_font);
   /* ja:システムフォント */
@@ -60,16 +63,7 @@ signal_style_set (GtkWidget *widget,
         system_font_height = height;
     }
   for (i = orz_mdi_get_n_pages (ORZ_MDI (mdi)) - 1; i >= 0; i--)
-    {
-      VmaidWindow *vmaid;
-
-      vmaid = orz_mdi_get_data (ORZ_MDI (mdi), i);
-      gtk_widget_set_usize (vmaid->drawing, vmaid->width * 3 + 4,
-                        system_font_height * 2 + ((vmaid->avi_edit[0] ? 1 : 0)
-                            + (vmaid->avi_edit[1] ? 1 : 0)) * vmaid->height);
-      gtk_widget_queue_resize (GTK_WIDGET (window));
-      gtk_widget_draw (vmaid->drawing, NULL);
-    }
+    set_usize (orz_mdi_get_data (ORZ_MDI (mdi), i));
 }
 
 
@@ -197,7 +191,7 @@ signal_drag_data_received (GtkWidget        *widget,
   gint i;
   FileOpen *file_open;
 
-  files = g_strsplit (selection_data->data, "\r\n", 0);
+  files = g_strsplit ((const gchar *)selection_data->data, "\r\n", 0);
   for (i = 0; files[i]; i++)
     {
       file = g_filename_from_uri (files[i], NULL, NULL);
@@ -217,227 +211,147 @@ signal_drag_data_received (GtkWidget        *widget,
 }
 
 
-gboolean
-signal_selection_clear (GtkWidget         *widget,
-                        GdkEventSelection *event,
-                        gpointer           user_data)
-{
-  if (event->selection == GDK_SELECTION_CLIPBOARD)
-    {
-      /* ja:クリップボード */
-      g_free (clipboard_scenario);
-      clipboard_scenario = NULL;
-    }
-  return TRUE;
-}
-
-
 void
-signal_selection_get (GtkWidget        *widget,
-                      GtkSelectionData *data,
-                      guint             info,
-                      guint             time,
-                      gpointer          user_data)
+signal_selection_paste (GObject   *object,
+                        AviEdit  **avi_edit,
+                        gpointer   user_data)
 {
-  /* ja:クリップボード */
-  if (data->selection == GDK_SELECTION_CLIPBOARD
-                                && clipboard_scenario && info == TARGET_VMAID)
-    gtk_selection_data_set (data, atom_scenario, 8,
-                (guchar *)clipboard_scenario, g_strlen (clipboard_scenario));
-}
+  gboolean result = TRUE, paste[2];
+  gint i, max, sx, page_num;
+  VmaidWindow *vmaid;
+  VmaidHistory *d;
 
-
-void
-signal_selection_received (GtkWidget        *widget,
-                           GtkSelectionData *data,
-                           guint             time,
-                           gpointer          user_data)
-{
-  if (data->selection == GDK_SELECTION_CLIPBOARD && data->length >= 0)
+  /* ja:貼り付け */
+  if (!avi_edit)
+    return;
+  page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
+  vmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
+  if (vmaid->select.stream < 0)
     {
-      /* ja:クリップボード */
-      gint i;
-
-      if (data->type == GDK_SELECTION_TYPE_ATOM)
+      /* ja:選択範囲がないときUNDOの準備 */
+      d = g_malloc0 (sizeof (VmaidHistory));
+      for (i = 0; i < 2; i++)
+        if (vmaid->avi_edit[i]
+                    && !(d->avi_edit[i] = avi_edit_dup (vmaid->avi_edit[i])))
+          result = FALSE;
+      if (!result)
         {
-          gint count;
-          GdkAtom *atoms;
+          GtkWidget *dialog;
 
-          atoms = (GdkAtom *)data->data;
-          count = data->length / sizeof (GdkAtom);
-          for (i = 0; i < count; i++)
-            if (atoms[i] == atom_scenario)
-              break;
-          if (i < count)
-            gtk_selection_convert (widget, data->selection,atoms[i],
-                                                            GDK_CURRENT_TIME);
-        }
-      else if (data->type == atom_scenario)
-        {
-          gboolean result = TRUE, paste[2];
-          gint max, sx, page_num;
-          AviEdit **avi_edit;
-          VmaidWindow *vmaid;
-          VmaidHistory *d;
-
-          /* ja:貼り付け */
-          avi_edit = avi_from_scenario (data->data);
-          if (!avi_edit)
-            return;
-          page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-          vmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
-          if (vmaid->select.stream < 0)
-            {
-              /* ja:選択範囲がないときUNDOの準備 */
-              d = g_malloc0 (sizeof (VmaidHistory));
-              for (i = 0; i < 2; i++)
-                if (vmaid->avi_edit[i]
-                        && !(d->avi_edit[i] = avi_clone (vmaid->avi_edit[i])))
-                  result = FALSE;
-              if (!result)
-                {
-                  GtkWidget *dialog;
-
-                  dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("AVI Clone Error"));
-                  g_signal_connect (G_OBJECT (dialog), "key-press-event",
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
                                     G_CALLBACK (misc_dialog_key_press), NULL);
-                  gtk_dialog_run (GTK_DIALOG (dialog));
-                  gtk_widget_destroy (dialog);
-                  for (i = 0; i < 2; i++)
-                    if (d->avi_edit[i])
-                      avi_release (d->avi_edit[i]);
-                  g_free (d);
-                  for (i = 0; avi_edit[i]; i++)
-                    avi_release (avi_edit[i]);
-                  g_free (avi_edit);
-                  return;
-                }
-              d->cursor = vmaid->cursor;
-              d->select = vmaid->select;
-              d->next = vmaid->undo;
-              vmaid->undo = d;
-            }
-          else
+          gtk_dialog_run (GTK_DIALOG (dialog));
+          gtk_widget_destroy (dialog);
+          for (i = 0; i < 2; i++)
+            if (d->avi_edit[i])
+              avi_edit_close (d->avi_edit[i]);
+          g_free (d);
+          return;
+        }
+      d->cursor = vmaid->cursor;
+      d->select = vmaid->select;
+      d->next = vmaid->undo;
+      vmaid->undo = d;
+    }
+  else
+    {
+      /* ja:選択範囲があればそれを削除する */
+      d = vmaid->redo;
+      vmaid->redo = NULL;
+      command_delete (window, NULL);
+      vmaid->redo = d;
+    }
+  paste[0] = paste[1] = FALSE;
+  for (i = 0; avi_edit[i]; i++)
+    switch (avi_edit_type (avi_edit[i]))
+      {
+        case AVI_TYPE_VIDEO:
+          if (!paste[0])
             {
-              /* ja:選択範囲があればそれを削除する */
-              d = vmaid->redo;
-              vmaid->redo = NULL;
-              command_delete (widget, NULL);
-              vmaid->redo = d;
-            }
-          paste[0] = paste[1] = FALSE;
-          for (i = 0; avi_edit[i]; i++)
-            switch (avi_type (avi_edit[i]))
-              {
-                case AVI_TYPE_VIDEO:
-                  if (paste[0])
-                    {
-                      avi_release (avi_edit[i]);
-                    }
-                  else
-                    {
-                      if (!vmaid->avi_edit[0])
-                        {
-                          vmaid->avi_edit[0] = avi_edit[i];
-                        }
-                      else if (!avi_paste (vmaid->avi_edit[0],
+              if (!vmaid->avi_edit[0])
+                {
+                  vmaid->avi_edit[0] = avi_edit_dup (avi_edit[i]);
+                }
+              else if (!avi_edit_paste (vmaid->avi_edit[0],
                                         MIN (vmaid->cursor.frame,
-                                            avi_length (vmaid->avi_edit[0])),
-                                                                avi_edit[i]))
-                        {
-                          avi_release (avi_edit[i]);
-                          result = FALSE;
-                        }
-                      paste[0] = TRUE;
-                    }
-                  break;
-                case AVI_TYPE_AUDIO:
-                  if (paste[1])
-                    {
-                      avi_release (avi_edit[i]);
-                    }
-                  else
-                    {
-                      if (!vmaid->avi_edit[1])
-                        {
-                          vmaid->avi_edit[1] = avi_edit[i];
-                        }
-                      else if (!avi_paste (vmaid->avi_edit[1],
+                                        avi_edit_length (vmaid->avi_edit[0])),
+                                                avi_edit_dup (avi_edit[i])))
+                result = FALSE;
+              paste[0] = TRUE;
+            }
+          break;
+        case AVI_TYPE_AUDIO:
+          if (!paste[1])
+            {
+              if (!vmaid->avi_edit[1])
+                {
+                  vmaid->avi_edit[1] = avi_edit_dup (avi_edit[i]);
+                }
+              else if (!avi_edit_paste (vmaid->avi_edit[1],
                             MIN (avi_time_to_sample (vmaid->avi_edit[1],
                                 (gint)((glonglong)vmaid->cursor.frame * 1000
                                                 * vmaid->scale / vmaid->rate)),
-                                        avi_length (vmaid->avi_edit[1])),
-                                                                avi_edit[i]))
-                        {
-                          avi_release (avi_edit[i]);
-                          result = FALSE;
-                        }
-                      paste[1] = TRUE;
-                    }
-                  break;
-                default:
-                  avi_release (avi_edit[i]);
-                  result = FALSE;
-              }
-          g_free (avi_edit);
-          if (!result || (!paste[0] && !paste[1]))
-            {
-              GtkWidget *dialog;
+                                        avi_edit_length (vmaid->avi_edit[1])),
+                                                avi_edit_dup (avi_edit[i])))
+                result = FALSE;
+              paste[1] = TRUE;
+            }
+          break;
+        default:
+          result = FALSE;
+        }
+  if (!result || (!paste[0] && !paste[1]))
+    {
+      GtkWidget *dialog;
 
-              dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("AVI Paste Error"));
-              g_signal_connect (G_OBJECT (dialog), "key-press-event",
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
                                     G_CALLBACK (misc_dialog_key_press), NULL);
-              gtk_dialog_run (GTK_DIALOG (dialog));
-              gtk_widget_destroy (dialog);
-              for (i = 0; i < 2; i++)
-                if (vmaid->avi_edit[i])
-                  avi_release (vmaid->avi_edit[i]);
-              d = vmaid->undo;
-              vmaid->undo = vmaid->undo->next;
-              for (i = 0; i < 2; i++)
-                vmaid->avi_edit[i] = d->avi_edit[i];
-              g_free (d);
-              return;
-            }
-          if (vmaid->avi_edit[0])
-            {
-              vmaid->rate = avi_get_rate (vmaid->avi_edit[0]);
-              vmaid->scale = avi_get_scale (vmaid->avi_edit[0]);
-            }
-          max = get_max_frame (vmaid, -1) + 1;
-          sx = MAX ((vmaid->drawing->allocation.width - 4)
-                                                        / vmaid->width - 2, 1);
-          if (vmaid->avi_edit[0] && !vmaid->avi_edit[1])
-            vmaid->cursor.stream = 0;
-          else if (!vmaid->avi_edit[0] && vmaid->avi_edit[1])
-            vmaid->cursor.stream = 1;
-          if (vmaid->cursor.frame > max)
-            vmaid->cursor.frame = max;
-          /* ja:キャレットが表示されるように調整 */
-          if (vmaid->top > vmaid->cursor.frame)
-            vmaid->top = MIN (vmaid->cursor.frame, max - sx);
-          if (vmaid->top < vmaid->cursor.frame - sx)
-            vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
-          /* ja:メニュー,ステートメント,子ウインドウ */
-          set_menu_bar (vmaid);
-          gtk_widget_set_usize (vmaid->drawing, vmaid->width * 3 + 4,
-                        system_font_height * 2 + ((vmaid->avi_edit[0] ? 1 : 0)
-                            + (vmaid->avi_edit[1] ? 1 : 0)) * vmaid->height);
-          gtk_widget_queue_resize (GTK_WIDGET (window));
-          gtk_widget_draw (vmaid->drawing, NULL);
-          draw_caret (vmaid, NULL);
-          misc_set_scroll_bar (vmaid->hscroll,
+      gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
+      for (i = 0; i < 2; i++)
+        if (vmaid->avi_edit[i])
+          avi_edit_close (vmaid->avi_edit[i]);
+      d = vmaid->undo;
+      vmaid->undo = vmaid->undo->next;
+      for (i = 0; i < 2; i++)
+        vmaid->avi_edit[i] = d->avi_edit[i];
+      g_free (d);
+      return;
+    }
+  if (vmaid->avi_edit[0])
+    {
+      vmaid->rate = avi_edit_get_rate (vmaid->avi_edit[0]);
+      vmaid->scale = avi_edit_get_scale (vmaid->avi_edit[0]);
+    }
+  max = get_max_frame (vmaid, -1) + 1;
+  sx = get_sx_frame (vmaid);
+  if (vmaid->avi_edit[0] && !vmaid->avi_edit[1])
+    vmaid->cursor.stream = 0;
+  else if (!vmaid->avi_edit[0] && vmaid->avi_edit[1])
+    vmaid->cursor.stream = 1;
+  if (vmaid->cursor.frame > max)
+    vmaid->cursor.frame = max;
+  /* ja:キャレットが表示されるように調整 */
+  if (vmaid->top > MIN (vmaid->cursor.frame, max - sx))
+    vmaid->top = MIN (vmaid->cursor.frame, max - sx);
+  if (vmaid->top < MAX (vmaid->cursor.frame - sx, 0))
+    vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
+  /* ja:メニュー,ステートメント,子ウインドウ */
+  set_menu_bar (vmaid);
+  set_usize (vmaid);
+  draw_caret (vmaid, NULL);
+  misc_set_scroll_bar (vmaid->hscroll,
                                 GTK_SIGNAL_FUNC (signal_value_changed_hscroll),
                                                 vmaid, 0, max, sx, vmaid->top);
-          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
-        }
-    }
+  orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
 }
 
 
